@@ -16,7 +16,7 @@ use Mail::Header;
 use vars qw($VERSION);
 
 BEGIN {
-    $VERSION = "1.43";
+    $VERSION = "1.45";
     *AUTOLOAD = \&AutoLoader::AUTOLOAD;
 
     unless(defined &UNIVERSAL::isa) {
@@ -533,9 +533,10 @@ sub _prephdr {
 
     $hdr->delete('Received');
 
-    $hdr->replace('X-Mailer', "Perl5 Mail::Internet v" . $Mail::Internet::VERSION);
+    $hdr->replace('X-Mailer', "Perl5 Mail::Internet v".$Mail::Internet::VERSION)
+        unless $hdr->count('X-Mailer');
 
-    my $name = eval { local $SIG{__DIE__}; (getpwuid($>))[6] } || $ENV{NAME} || "";
+    my $name = eval {local $SIG{__DIE__}; (getpwuid($>))[6]} || $ENV{NAME} ||"";
 
     while($name =~ s/\([^\(\)]*\)//) { 1; }
 
@@ -564,7 +565,7 @@ use Net::Domain qw(hostname);
 use Net::SMTP;
 use strict;
 
-sub smtpsend 
+ sub smtpsend 
 {
     my $src  = shift;
     my %opt = @_;
@@ -745,6 +746,10 @@ Mail::Internet - manipulate Internet format (RFC 822) mail messages
 This package provides a class object which can be used for reading, creating,
 manipulating and writing a message with RFC822 compliant headers.
 
+If you start writing a new application, you may want to use the
+L<Mail::Box> set of packages (requires perl 5.6.1), which has more
+features.  See http://perl.overmeer.net/mailbox.
+
 =head1 CONSTRUCTOR
 
 =over 4
